vcl/inc/win/salgdi.h    |    6 +++---
 vcl/win/gdi/salfont.cxx |   22 +++++++++++-----------
 2 files changed, 14 insertions(+), 14 deletions(-)

New commits:
commit 232992fa65358e7bc493c9f19f724457eed4feb5
Author:     Caolán McNamara <caol...@redhat.com>
AuthorDate: Tue Aug 21 09:12:16 2018 +0100
Commit:     Caolán McNamara <caol...@redhat.com>
CommitDate: Tue Aug 21 21:35:55 2018 +0200

    can now use just FontSelectPatternAttributes
    
    Change-Id: I1857afa0a9aff39118ba3c242134985f865e37c1
    Reviewed-on: https://gerrit.libreoffice.org/59387
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caol...@redhat.com>
    Tested-by: Caolán McNamara <caol...@redhat.com>

diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index c55193e255e9..ebb9fc8eac3d 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -42,7 +42,7 @@
 #include <hb-ot.h>
 #include <dwrite.h>
 
-class FontSelectPattern;
+class FontSelectPatternAttributes;
 class WinFontInstance;
 class ImplFontAttrCache;
 class OpenGLTexture;
@@ -185,7 +185,7 @@ private:
 
     bool CacheGlyphs(const GenericSalLayout& rLayout);
     bool DrawCachedGlyphs(const GenericSalLayout& rLayout);
-    HFONT ImplDoSetFont(FontSelectPattern const & i_rFont, const 
PhysicalFontFace * i_pFontFace, float& o_rFontScale, HFONT& o_rOldFont);
+    HFONT ImplDoSetFont(FontSelectPatternAttributes const & i_rFont, const 
PhysicalFontFace * i_pFontFace, float& o_rFontScale, HFONT& o_rOldFont);
 
 public:
     HDC getHDC() const { return mhLocalDC; }
@@ -402,7 +402,7 @@ public:
 // Init/Deinit Graphics
 void    ImplUpdateSysColorEntries();
 int     ImplIsSysColorEntry( Color nColor );
-void    ImplGetLogFontFromFontSelect( HDC, const FontSelectPattern*,
+void    ImplGetLogFontFromFontSelect( HDC, const FontSelectPatternAttributes*,
             const PhysicalFontFace*, LOGFONTW& );
 
 #define MAX_64KSALPOINTS    ((((sal_uInt16)0xFFFF)-8)/sizeof(POINTS))
diff --git a/vcl/win/gdi/salfont.cxx b/vcl/win/gdi/salfont.cxx
index a51a06a0d4c4..3fe7b6171453 100644
--- a/vcl/win/gdi/salfont.cxx
+++ b/vcl/win/gdi/salfont.cxx
@@ -179,10 +179,10 @@ bool 
WinGlyphFallbackSubstititution::HasMissingChars(PhysicalFontFace* pFace, OU
     FontCharMapRef xFontCharMap = pWinFont->GetFontCharMap();
     if( !xFontCharMap.is() )
     {
-        // construct a Size structure as the parameter of constructor of class 
FontSelectPattern
+        // construct a Size structure as the parameter of constructor of class 
FontSelectPatternAttributes
         const Size aSize( pFace->GetWidth(), pFace->GetHeight() );
-        // create a FontSelectPattern object for getting s LOGFONT
-        const FontSelectPattern aFSD( *pFace, aSize, 
static_cast<float>(aSize.Height()), 0, false );
+        // create a FontSelectPatternAttributes object for getting s LOGFONT
+        const FontSelectPatternAttributes aFSD( *pFace, aSize, 
static_cast<float>(aSize.Height()), 0, false );
         // construct log font
         LOGFONTW aLogFont;
         ImplGetLogFontFromFontSelect( mhDC, &aFSD, pFace, aLogFont );
@@ -760,7 +760,7 @@ int CALLBACK SalEnumQueryFontProcExW( const LOGFONTW*,
 }
 
 void ImplGetLogFontFromFontSelect( HDC hDC,
-                                   const FontSelectPattern* pFont,
+                                   const FontSelectPatternAttributes* pFont,
                                    const PhysicalFontFace* pFontFace,
                                    LOGFONTW& rLogFont )
 {
@@ -842,7 +842,7 @@ void ImplGetLogFontFromFontSelect( HDC hDC,
     }
 }
 
-HFONT WinSalGraphics::ImplDoSetFont(FontSelectPattern const & i_rFont,
+HFONT WinSalGraphics::ImplDoSetFont(FontSelectPatternAttributes const & 
i_rFont,
                                     const PhysicalFontFace * i_pFontFace,
                                     float& o_rFontScale,
                                     HFONT& o_rOldFont)
@@ -1647,10 +1647,10 @@ bool WinSalGraphics::CreateFontSubset( const OUString& 
rToFile,
 {
     // TODO: use more of the central font-subsetting code, move stuff there if 
needed
 
     // create matching FontSelectPattern
     // we need just enough to get to the font file data
     // use height=1000 for easier debugging (to match psprint's font units)
-    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false 
);
 
     // TODO: much better solution: move SetFont and restoration of old font to 
caller
     ScopedFont aOldFont(*this);
@@ -1769,9 +1769,9 @@ bool WinSalGraphics::CreateFontSubset( const OUString& 
rToFile,
 
 const void* WinSalGraphics::GetEmbedFontData(const PhysicalFontFace* pFont, 
long* pDataLen)
 {
     // create matching FontSelectPattern
     // we need just enough to get to the font file data
-    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false 
);
 
     ScopedFont aOldFont(*this);
 
@@ -1799,9 +1799,9 @@ void WinSalGraphics::GetGlyphWidths( const 
PhysicalFontFace* pFont,
                                      std::vector< sal_Int32 >& rWidths,
                                      Ucs2UIntMap& rUnicodeEnc )
 {
     // create matching FontSelectPattern
     // we need just enough to get to the font file data
-    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false 
);
 
     // TODO: much better solution: move SetFont and restoration of old font to 
@@ -1647,10 +1647,10 @@ bool WinSalGraphics::CreateFontSubset( const OUString& 
needed
 
-    // create matching FontSelectPattern
+    // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
     // use height=1000 for easier debugging (to match psprint's font units)
@@ -1769,9 +1769,9 @@ bool WinSalGraphics::CreateFontSubset( const OUString& 
long* pDataLen)
 {
-    // create matching FontSelectPattern
+    // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
@@ -1799,9 +1799,9 @@ void WinSalGraphics::GetGlyphWidths( const 
                                      Ucs2UIntMap& rUnicodeEnc )
 {
-    // create matching FontSelectPattern
+    // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
caller
     ScopedFont aOldFont(*this);
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to